@@ -5,7 +5,7 @@ import sys
 
 
 # Create a module we can import.
-lib = os.path.join(os.environ['ADTTMP'], 'lib')
+lib = os.path.join(os.environ['AUTOPKGTEST_TMP'], 'lib')
 os.makedirs(lib)
 
 path = os.path.join(lib, 'module.py')
