@@ -1,4 +1,4 @@
-cd $ADTTMP
+cd $AUTOPKGTEST_TMP
 
 python3 -c "import public; print(public)"
 python3 -c "import public; print(public.__version__)"
